//******************************************************************************
///
/// @file parser/_keywords.h
///
/// This header file contains static character string arrays used primarily to
/// drive documentation associated with the yuqk fork of POV-Ray. The arrays are
/// used in the final executable to provide for scene description language (SDL)
/// functions word_is() and word_get(). The active function names array is used
/// with the 'no lower case, user identifier' checking if the executable is
/// compiled with that option (NO_LC_USER_IDENTIFIERS).
///
/// The arrays are maintained in several files in total:
///     _directivewords.h, _fakebyfnctwords.h, _fnnames.h, _keywords.h,
///     _oddwords.h and _optionnames.h.
///
/// @copyright
/// @parblock
///
/// Persistence of Vision Ray Tracer ('POV-Ray') version 3.8.
/// Copyright 1991-2023 Persistence of Vision Raytracer Pty. Ltd.
///
/// POV-Ray is free software: you can redistribute it and/or modify
/// it under the terms of the GNU Affero General Public License as
/// published by the Free Software Foundation, either version 3 of the
/// License, or (at your option) any later version.
///
/// POV-Ray is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU Affero General Public License for more details.
///
/// You should have received a copy of the GNU Affero General Public License
/// along with this program.  If not, see <http://www.gnu.org/licenses/>.
///
/// ----------------------------------------------------------------------------
///
/// POV-Ray is based on the popular DKB raytracer version 2.12.
/// DKBTrace was originally written by David K. Buck.
/// DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
///
/// @endparblock
///
//------------------------------------------------------------------------------
// SPDX-License-Identifier: AGPL-3.0-or-later
//******************************************************************************

#ifndef POVRAY_PARSER__KEYWORDS_H
#define POVRAY_PARSER__KEYWORDS_H

static char iKeyWords[][26] { "aa_level", "aa_threshold", "abs", "absorption", "accuracy", "acos", "acosh", "adaptive",
    "adc_bailout", "agate", "albedo", "all", "altitude", "always_sample", "ambient", "amplify", "angle", "anisotropy",
    "aoi", "aperture", "append", "arc_angle", "area_illumination", "area_light", "array", "asc", "ascii", "asin",
    "asinh", "assumed_gamma", "atan", "atan2", "atanh", "autostop", "average", "b_spline", "background", "bevy",
    "bezier_spline", "bicubic_patch", "bitwise_and", "bitwise_or", "bitwise_xor", "black_hole", "blend_gamma",
    "blend_mode", "blob", "blue", "blur_samples", "bmp", "bokeh", "bool_object", "bounded_by", "box", "boxed", "bozo",
    "brick", "brick_size", "brightness", "brilliance", "bt2020", "bt709", "bump_map", "bump_size", "bumps", "camera",
    "caustics", "ceil", "cells", "charset", "checker", "chr", "circular", "clipped_by", "clock", "clock_delta",
    "clock_on", "cmap", "dens_object", "collect", "color", "color_map", "colour", "colour_map", "concat", "cone",
    "confidence", "conic_sweep", "conserve_energy", "contained_by", "control0", "control1", "coords", "cos", "cosh",
    "count", "crackle", "crand", "cubic", "cubic_spline", "cubic_wave", "cutaway_textures", "cylinder", "cylindrical",
    "datetime", "default", "defined", "degrees", "density", "density_file", "density_map", "dents", "df3", "dictionary",
    "difference", "diffuse", "dimension_size", "dimensions", "direction", "disc", "dispersion", "dispersion_samples",
    "dist_exp", "distance", "div", "double_illuminate", "e", "eccentricity", "emission", "error_bound", "exp",
    "expand_thresholds", "exponent", "exr", "exterior", "extinction", "face_indices", "facets", "fade_color",
    "fade_colour", "fade_distance", "fade_power", "falloff", "falloff_angle", "false", "file_exists", "filter",
    "final_clock", "final_frame", "finish", "fisheye", "flatness", "flip", "floor", "focal_point", "fog", "fork_str",
    "fork_val", "form", "frame_number", "frequency", "fresnel", "function", "function_interval", "gamma", "gather",
    "getenv", "gif", "global", "global_lights", "global_settings", "gradient", "granite", "gray", "gray_threshold",
    "green", "grey", "grey_threshold", "grooved", "hard_object", "hdr", "height_field", "hexagon", "hi", "hierarchy",
    "hollow", "id_type", "iff", "image_height", "image_map", "image_pattern", "image_width", "importance",
    "initial_clock", "initial_frame", "input_file_name", "inside", "inside_vector", "int", "intensity_max", "interior",
    "interior_texture", "internal", "interpolate", "intersection", "intervals", "inv_pnormal_cure", "inverse", "ior",
    "ip_count", "ip_fade_distance", "ip_frequency", "ip_phase", "ip_scale", "ip_seed", "irid", "irid_wavelength",
    "isosurface", "it_amount", "it_depth", "it_frequency", "it_lambda", "it_octaves", "it_omega", "it_scale",
    "it_translate", "jitter", "jpeg", "julia", "lambda", "lathe", "lemon", "leopard", "light_group", "light_source",
    "linear_spline", "linear_sweep", "list_object", "ln", "lo", "load_file", "local", "location", "log", "log2",
    "look_at", "looks_like", "low_error_factor", "magnet", "major_radius", "mandel", "map_type", "marble", "material",
    "material_map", "matrix", "max", "max_extent", "max_gradient", "max_sample", "max_trace", "max_trace_level",
    "maximum_reuse", "media", "media_attenuation", "media_interaction", "merge", "mesh", "mesh2", "mesh_camera",
    "metallic", "method", "metric", "micro", "min", "min_extent", "minimum_reuse", "mixed", "mm_per_unit", "mod",
    "mortar", "natural_spline", "nearest_count", "no", "no_bump_scale", "no_image", "no_radiosity", "no_reflection",
    "no_shadow", "noise_cubed", "noise_generator", "normal", "normal_indices", "normal_map", "normal_vectors", "now",
    "number_of_sides", "number_of_tiles", "object", "octaves", "off", "offset", "omega", "omnimax", "on", "once",
    "onion", "open", "optional", "orient", "orientation", "orthographic", "ovus", "panoramic", "parallel", "parametric",
    "pass_through", "pattern", "pattern_modifiers", "pavement", "perspective", "pgm", "phase", "phong", "phong_odebla",
    "phong_size", "photons", "pi", "pigment", "pigment_map", "pigment_pattern", "planar", "plane", "png", "point_at",
    "poly", "poly_wave", "polygon", "polynomial", "pot", "potential", "pow", "ppm", "precompute", "premultiplied",
    "pretrace_end", "pretrace_start", "prism", "prod", "projected_through", "quadratic_spline", "quadric", "quartic",
    "quick_color", "quick_colour", "quilted", "radial", "radians", "radiosity", "radius", "rainbow", "ramp_wave",
    "rand", "ratio", "raw_wave", "read", "recursion_limit", "red", "reflection", "refraction", "repeat", "report",
    "rgb", "rgbf", "rgbft", "rgbt", "right", "ripples", "rotate", "roughness", "samples", "save_file", "scale",
    "scallop_wave", "scattering", "seed", "seedfi", "select", "shadow_tolerance", "shadowless", "sin", "sine_wave",
    "sinh", "sint16be", "sint16le", "sint32be", "sint32le", "sint8", "size", "sky", "sky_sphere", "slope", "slope_map",
    "smooth", "smooth_triangle", "soft_object", "solid", "sor", "spacing", "specular", "specular_odebla", "sphere",
    "sphere_sweep", "spherical", "spiral1", "spiral2", "spline", "split_union", "spotlight", "sqr", "sqrt", "square",
    "srgb", "srgbf", "srgbft", "srgbt", "str", "strcmp", "strength", "strlen", "strlwr", "strupr", "sturm", "substr",
    "subsurface", "sum", "superellipsoid", "sys", "t", "tan", "tanh", "target", "tau", "text", "texture",
    "texture_list", "texture_map", "tga", "thickness", "threshold", "tiff", "tightness", "tiled", "tiling", "tolerance",
    "toroidal", "torus", "trace", "transform", "translate", "translucency", "transmit", "triangle", "triangle_wave",
    "triangular", "true", "ttf", "turbulence", "type", "u", "u_steps", "uint16be", "uint16le", "uint32be", "uint32le",
    "uint8", "ultra_wide_angle", "union", "unofficial", "up", "use_alpha", "use_color", "use_colour", "use_index",
    "user_defined", "utf8", "uv_indices", "uv_mapping", "uv_vectors", "v", "v_steps", "val", "variance", "vaxis_rotate",
    "vcross", "vdot", "version", "vertex_vectors", "vlength", "vnormalize", "vrotate", "vstr", "vturbulence", "warp",
    "water_level", "waves", "width", "wood", "word_get", "word_is", "wrinkles", "write", "x", "xyz", "y", "yes", "z" };

static char oKeyWords[][26] { "agate_turb", "all_intersections", "alpha", "ambient_light", "component", "composite",
    "cube", "deprecated", "dtag", "evaluate", "fclose", "fog_alt", "fog_offset", "fog_type", "fopen", "hf_gray_16",
    "hf_grey_16", "hypercomplex", "julia_fractal", "max_intersections", "max_iteration", "number_of_waves", "polarity",
    "precision", "pwr", "quaternion", "reciprocal", "reflection_exponent", "sblue", "sgreen", "slice", "spotted",
    "sred", "tile2", "tiles", "turb_depth" };

static char nKeyWords[][26] { "amplify", "bevy", "bool_object", "cmap", "dens_object", "e", "fork_str", "fork_val",
    "function_interval", "getenv", "grooved", "hard_object", "hi", "id_type", "intensity_max", "inv_pnormal_cure",
    "ip_count", "ip_fade_distance", "ip_frequency", "ip_phase", "ip_scale", "ip_seed", "it_amount", "it_depth",
    "it_frequency", "it_lambda", "it_octaves", "it_omega", "it_scale", "it_translate", "list_object", "lo", "log2",
    "micro", "noise_cubed", "pattern_modifiers", "phong_odebla", "raw_wave", "report", "seedfi", "shadow_tolerance",
    "soft_object", "specular_odebla", "tiled", "uint32be", "uint32le", "word_get", "word_is" };

#endif // POVRAY_PARSER__KEYWORDS_H
